@@ -13,7 +13,7 @@ use Digest::MD5 qw(md5_hex);
 use Errno;
 use Data::Dumper;
 our $AUTOLOAD;
-*VERSION = \'2.4.14.6';
+*VERSION = \'2.1';
 
 use constant { OK => 0, WARNING => 1, CRITICAL => 2, UNKNOWN => 3 };
 
@@ -26,7 +26,6 @@ use constant { OK => 0, WARNING => 1, CRITICAL => 2, UNKNOWN => 3 };
   our $extendedinfo = [];
   our $summary = [];
   our $variables = {};
-  our $survive_sudo_env = ["LD_LIBRARY_PATH", "SHLIB_PATH"];
 }
 
 sub new {
@@ -131,12 +130,6 @@ sub add_default_args {
    The tertiary name of a component",
       required => 0,
   );
-  $self->add_arg(
-      spec => 'extra-opts=s',
-      help => "--extra-opts
-   read command line arguments from an external file",
-      required => 0,
-  );
   $self->add_arg(
       spec => 'blacklist|b=s',
       help => '--blacklist
@@ -230,20 +223,7 @@ sub add_default_args {
       spec => 'reset',
       help => "--reset
    remove the state file",
-      required => 0,
-      hidden => 1,
-  );
-  $self->add_arg(
-      spec => 'runas=s',
-      help => "--runas
-   run as a different user",
-      required => 0,
-      hidden => 1,
-  );
-  $self->add_arg(
-      spec => 'shell',
-      help => "--shell
-   forget what you see",
+      aliasfor => "name",
       required => 0,
       hidden => 1,
   );
@@ -255,13 +235,6 @@ sub add_default_args {
       required => 0,
       hidden => 1,
   );
-  $self->add_arg(
-      spec => 'tracefile=s',
-      help => "--tracefile
-   Write debugging-info to this file (if it exists)",
-      required => 0,
-      hidden => 1,
-  );
 }
 
 sub add_modes {
@@ -402,10 +375,9 @@ sub set_timeout_alarm {
   my ($self, $timeout, $handler) = @_;
   $timeout ||= $self->opts->timeout;
   $handler ||= sub {
-    $self->nagios_exit(UNKNOWN,
-        sprintf("%s timed out after %d seconds\n",
-            $Monitoring::GLPlugin::plugin->{name}, $self->opts->timeout)
-    );
+    printf "UNKNOWN - %s timed out after %d seconds\n",
+        $Monitoring::GLPlugin::plugin->{name}, $self->opts->timeout;
+    exit 3;
   };
   use POSIX ':signal_h';
   if ($^O =~ /MSWin/) {
@@ -437,9 +409,7 @@ sub get_variable {
 
 sub debug {
   my ($self, $format, @message) = @_;
-  my $tracefile = $self->opts->tracefile ?
-      $self->opts->tracefile :
-      "/tmp/".$Monitoring::GLPlugin::pluginname.".trace";
+  my $tracefile = "/tmp/".$Monitoring::GLPlugin::pluginname.".trace";
   $self->{trace} = -f $tracefile ? 1 : 0;
   if ($self->get_variable("verbose") &&
       $self->get_variable("verbose") > $self->get_variable("verbosity", 10)) {
@@ -550,21 +520,21 @@ sub accentfree {
 }
 
 sub dump {
-  my ($self, $indent) = @_;
-  $indent = $indent ? " " x $indent : "";
+  my ($self) = @_;
   my $class = ref($self);
   $class =~ s/^.*:://;
   if (exists $self->{flat_indices}) {
-    printf "%s[%s_%s]\n", $indent, uc $class, $self->{flat_indices};
+    printf "[%s_%s]\n", uc $class, $self->{flat_indices};
   } else {
-    printf "%s[%s]\n", $indent, uc $class;
+    printf "[%s]\n", uc $class;
   }
   foreach (grep !/^(info|trace|warning|critical|blacklisted|extendedinfo|flat_indices|indices)$/, sort keys %{$self}) {
-    printf "%s%s: %s\n", $indent, $_, $self->{$_} if defined $self->{$_} && ref($self->{$_}) ne "ARRAY";
+    printf "%s: %s\n", $_, $self->{$_} if defined $self->{$_} && ref($self->{$_}) ne "ARRAY";
   }
   if ($self->{info}) {
-    printf "%sinfo: %s\n", $indent, $self->{info};
+    printf "info: %s\n", $self->{info};
   }
+  printf "\n";
   foreach (grep !/^(info|trace|warning|critical|blacklisted|extendedinfo|flat_indices|indices)$/, sort keys %{$self}) {
     if (defined $self->{$_} && ref($self->{$_}) eq "ARRAY") {
       my $have_flat_indices = 1;
@@ -583,11 +553,8 @@ sub dump {
           $obj->dump() if UNIVERSAL::can($obj, "isa") && $obj->can("dump");
         }
       }
-    } elsif (defined $self->{$_} && ref($self->{$_}) =~ /^Classes::/) {
-      $self->{$_}->dump(2) if UNIVERSAL::can($self->{$_}, "isa") && $self->{$_}->can("dump");
     }
   }
-  printf "\n";
 }
 
 sub table_ascii {
@@ -669,7 +636,6 @@ sub load_my_extension {
     }
     my $plugin_name = $Monitoring::GLPlugin::pluginname;
     $plugin_name =~ /check_(.*?)_health/;
-    my $deprecated_class = "DBD::".(uc $1)."::Server";
     $plugin_name = "Check".uc(substr($1, 0, 1)).substr($1, 1)."Health";
     foreach my $libpath (split(":", $self->opts->get("with-mymodules-dyn-dir"))) {
       foreach my $extmod (glob $libpath."/".$plugin_name."*.pm") {
@@ -692,8 +658,7 @@ sub load_my_extension {
     my $original_init = $self->can("init");
     $self->compatibility_class() if $self->can('compatibility_class');
     bless $self, "My$class";
-    $self->compatibility_methods() if $self->can('compatibility_methods') &&
-        $self->isa($deprecated_class);
+    $self->compatibility_methods() if $self->can('compatibility_methods');
     if ($self->isa("Monitoring::GLPlugin")) {
       my $new_init = $self->can("init");
       if ($new_init == $original_init) {
@@ -785,8 +750,6 @@ sub opts { # die beiden _nicht_ in AUTOLOAD schieben, das kracht!
 sub getopts {
   my ($self, $envparams) = @_;
   $envparams ||= [];
-  my $needs_restart = 0;
-  my @restart_opts = ();
   $Monitoring::GLPlugin::plugin->getopts();
   # es kann sein, dass beim aufraeumen zum schluss als erstes objekt
   # das $Monitoring::GLPlugin::plugin geloescht wird. in anderen destruktoren
@@ -807,83 +770,8 @@ sub getopts {
       exit 3;
     }
   }
-  if ($self->opts->environment) {
-    # wenn die gewuenschten Environmentvariablen sich von den derzeit
-    # gesetzten unterscheiden, dann restart. Denn $ENV aendert
-    # _nicht_ das Environment des laufenden Prozesses. 
-    # $ENV{ZEUGS} = 1 bedeutet lediglich, dass $ENV{ZEUGS} bei weiterer
-    # Verwendung 1 ist, bedeutet aber _nicht_, dass diese Variable 
-    # im Environment des laufenden Prozesses existiert.
-    foreach (keys %{$self->opts->environment}) {
-      if ((! $ENV{$_}) || ($ENV{$_} ne $self->opts->environment->{$_})) {
-        $needs_restart = 1;
-        $ENV{$_} = $self->opts->environment->{$_};
-        $self->debug(sprintf "new %s=%s forces restart\n", $_, $ENV{$_});
-      }
-    }
-  }
-  if ($self->opts->runas) {
-    # exec sudo $0 ... und dann ohne --runas
-    $needs_restart = 1;
-    # wenn wir environmentvariablen haben, die laut survive_sudo_env als
-    # wichtig erachtet werden, dann muessen wir die ueber einen moeglichen
-    # sudo-aufruf rueberretten, also in zusaetzliche --environment umwandenln.
-    # sudo putzt das Environment naemlich aus.
-    foreach my $survive_env (@{$Monitoring::GLPlugin::survive_sudo_env}) {
-      if ($ENV{$survive_env} && ! scalar(grep { /^$survive_env=/ }
-          keys %{$self->opts->environment})) {
-        $self->opts->environment->{$survive_env} = $ENV{$survive_env};
-        printf STDERR "add important --environment %s=%s\n",
-            $survive_env, $ENV{$survive_env} if $self->opts->verbose >= 2;
-        push(@restart_opts, '--environment');
-        push(@restart_opts, sprintf '%s=%s',
-            $survive_env, $ENV{$survive_env});
-      }
-    }
-  }
-  if ($needs_restart) {
-    foreach my $option (keys %{$self->opts->all_my_opts}) {
-      # der fliegt raus, sonst gehts gleich wieder in needs_restart rein
-      next if $option eq "runas";
-      foreach my $spec (map { $_->{spec} } @{$Monitoring::GLPlugin::plugin->opts->{_args}}) {
-        if ($spec =~ /^(\w+)=(.*)/) {
-          if ($1 eq $option && $2 =~ /s%/) {
-            foreach (keys %{$self->opts->$option()}) {
-              push(@restart_opts, sprintf "--%s", $option);
-              push(@restart_opts, sprintf "%s=%s", $_, $self->opts->$option()->{$_});
-            }
-          } elsif ($1 eq $option) {
-            push(@restart_opts, sprintf "--%s", $option);
-            push(@restart_opts, sprintf "%s", $self->opts->$option());
-          }
-        } elsif ($spec eq $option) {
-          push(@restart_opts, sprintf "--%s", $option);
-        }
-      }
-    }
-    if ($self->opts->runas && ($> == 0)) {
-      # Ja, es gibt so Narrische, die gehen mit check_by_ssh als root
-      # auf Datenbankmaschinen drauf und lassen dann dort check_oracle_health
-      # laufen. Damit OPS$-Anmeldung dann funktioniert, wird mit --runas
-      # auf eine andere Kennung umgeschwenkt. Diese Kennung gleich fuer
-      # ssh zu verwenden geht aus Sicherheitsgruenden nicht. Narrische halt.
-      exec "su", "-c", sprintf("%s %s", $0, join(" ", @restart_opts)), "-", $self->opts->runas;
-    } elsif ($self->opts->runas) {
-      exec "sudo", "-S", "-u", $self->opts->runas, $0, @restart_opts;
-    } else {
-      exec $0, @restart_opts;
-      # dadurch werden SHLIB oder LD_LIBRARY_PATH sauber gesetzt, damit beim
-      # erneuten Start libclntsh.so etc. gefunden werden.
-    }
-    exit;
-  }
-  if ($self->opts->shell) {
-    # So komme ich bei den Narrischen zu einer root-Shell.
-    system("/bin/sh");
-  }
 }
 
-
 sub add_ok {
   my ($self, $message) = @_;
   $message ||= $self->{info};
@@ -1211,13 +1099,12 @@ sub valdiff {
           if ($date >= ($now - $self->opts->lookback)) {
             $last_values->{$_} = $last_values->{lookback_history}->{$_}->{$date};
             $last_values->{timestamp} = $date;
-            $self->{'delta_timestamp'} = $now - $last_values->{timestamp};
             if (ref($last_values->{$_}) eq "ARRAY") {
               $self->debug(sprintf "oldest value of %s within lookback is size %s (age %d)",
-                  $_, scalar(@{$last_values->{$_}}), $now - $date);
+                  $_, scalar(@{$last_values->{$_}}), time - $date);
             } else {
               $self->debug(sprintf "oldest value of %s within lookback is %s (age %d)",
-                  $_, $last_values->{$_}, $now - $date);
+                  $_, $last_values->{$_}, time - $date);
             }
             last;
           } else {
@@ -1228,8 +1115,8 @@ sub valdiff {
       }
     }
     if ($mode eq "normal" || $mode eq "lookback" || $mode eq "lookback_freeze_chill") {
-      if (exists $self->{$_} && defined $self->{$_} && $self->{$_} =~ /^\d+\.*\d*$/) {
-        $last_values->{$_} = 0 if ! (exists $last_values->{$_} && defined $last_values->{$_});
+      if ($self->{$_} =~ /^\d+\.*\d*$/) {
+        $last_values->{$_} = 0 if ! exists $last_values->{$_};
         if ($self->{$_} >= $last_values->{$_}) {
           $self->{'delta_'.$_} = $self->{$_} - $last_values->{$_};
         } elsif ($self->{$_} eq $last_values->{$_}) {
@@ -1276,13 +1163,6 @@ sub valdiff {
         my @lost = grep(!defined $current{$_}, @{$last_values->{$_}});
         $self->{'delta_found_'.$_} = \@found;
         $self->{'delta_lost_'.$_} = \@lost;
-      } else {
-        # nicht ganz sauber, aber das artet aus, wenn man jedem uninitialized hinterherstochert.
-        # wem das nicht passt, der kann gerne ein paar tage debugging beauftragen.
-        # das kostet aber mehr als drei kugeln eis.
-        $last_values->{$_} = 0 if ! (exists $last_values->{$_} && defined $last_values->{$_});
-        $self->{$_} = 0 if ! (exists $self->{$_} && defined $self->{$_});
-        $self->{'delta_'.$_} = 0;
       }
     }
   }
@@ -1383,14 +1263,12 @@ sub protect_value {
   if (ref($validfunc) ne "CODE" && $validfunc eq "percent") {
     $validfunc = sub {
       my $value = shift;
-      return 0 if ! defined $value;
       return 0 if $value !~ /^[-+]?([0-9]+(\.[0-9]+)?|\.[0-9]+)$/;
       return ($value < 0 || $value > 100) ? 0 : 1;
     };
   } elsif (ref($validfunc) ne "CODE" && $validfunc eq "positive") {
     $validfunc = sub {
       my $value = shift;
-      return 0 if ! defined $value;
       return 0 if $value !~ /^[-+]?([0-9]+(\.[0-9]+)?|\.[0-9]+)$/;
       return ($value < 0) ? 0 : 1;
     };
@@ -1632,6 +1510,7 @@ sub compatibility_methods {
   }
 }
 
+
 sub AUTOLOAD {
   my ($self, @params) = @_;
   return if ($AUTOLOAD =~ /DESTROY/);
@@ -1659,9 +1538,9 @@ sub AUTOLOAD {
     $self->{components}->{$subsystem}->check();
     $self->{components}->{$subsystem}->dump()
         if $self->opts->verbose >= 2;
-  } elsif ($AUTOLOAD =~ /^.*::(status_code|check_messages|nagios_exit|html_string|perfdata_string|selected_perfdata|check_thresholds|get_thresholds|opts|pandora_string|strequal)$/) {
+  } elsif ($AUTOLOAD =~ /^.*::(status_code|check_messages|nagios_exit|html_string|perfdata_string|selected_perfdata|check_thresholds|get_thresholds|opts)$/) {
     return $Monitoring::GLPlugin::plugin->$1(@params);
-  } elsif ($AUTOLOAD =~ /^.*::(reduce_messages|reduce_messages_short|clear_messages|suppress_messages|add_html|add_perfdata|override_opt|create_opt|set_thresholds|force_thresholds|add_pandora)$/) {
+  } elsif ($AUTOLOAD =~ /^.*::(reduce_messages|reduce_messages_short|clear_messages|suppress_messages|add_html|add_perfdata|override_opt|create_opt|set_thresholds|force_thresholds)$/) {
     $Monitoring::GLPlugin::plugin->$1(@params);
   } elsif ($AUTOLOAD =~ /^.*::mod_arg_(.*)$/) {
     return $Monitoring::GLPlugin::plugin->mod_arg($1, @params);
