@@ -46,12 +46,6 @@ sub add_db_modes {
       alias => undef,
       help => 'the time an sql command needs to run',
   );
-  $self->add_mode(
-      internal => 'internal::encode',
-      spec => 'encode',
-      alias => undef,
-      help => 'url-encodes stdin',
-  );
 }
 
 sub add_db_args {
@@ -160,7 +154,7 @@ sub init {
     $self->clear_all() if $self->check_messages() &&
         defined $self->opts->mitigation && $self->opts->mitigation == 0;
     $self->set_thresholds(warning => 1, critical => 5);
-    $self->add_message($self->check_thresholds($runtime),
+    $self->add_nagios($self->check_thresholds($runtime),
         sprintf "%.2f seconds to execute %s",
             $runtime,
             $self->opts->name2 ? $self->opts->name2 : $self->opts->name);
@@ -412,6 +406,7 @@ sub fetchall_array_cached {
 
 sub DESTROY {
   my ($self) = @_;
+  $self->debug("try to clean up command and result files");
   $self->delete_extcmd_files();
 }
 
